@@ -7,7 +7,7 @@ from .hub_logger import HUBLogger
 from .utils.general import colorstr
 from .yolov5_wrapper import YOLOv5Wrapper as YOLOv5
 
-PREFIX = colorstr('Ultralytics HUB: ')
+PREFIX = colorstr('Ultralytics: ')
 
 
 class Trainer:
@@ -48,7 +48,9 @@ class Trainer:
                     "id"]  # Append id as it may be fetched from queue and unknown
                 return res["data"]
         except requests.exceptions.ConnectionError:
-            print(f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.')
+            print(
+                f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.'
+            )
             sys.exit(141)  # TODO: keep this 141 sys exit error code?
 
     def _connectCallbacks(self):
